pub struct Access {
pub process: u32,
pub path: String,
pub resolved_path: Option<String>,
pub keyed_path: Option<String>,
pub operation: Operation,
pub result: String,
pub category: Category,
}Fields
process: u32path: StringRelative to the workspace, or absolute for external accesses.
resolved_path: Option<String>Descriptor target when the backend provides it at access time.
keyed_path: Option<String>A declared symlink input that covers this observed target.
operation: Operationresult: Stringsuccess, missing, another errno, or unknown for Seatbelt events.
category: CategoryTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Access
impl<'de> Deserialize<'de> for Access
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more