TaskAnalysis

Struct TaskAnalysis 

pub struct TaskAnalysis {
Show 18 fields pub context: Value, pub outcome: String, pub coverage: Coverage, pub declared_files: BTreeSet<String>, pub mandatory_files: BTreeSet<String>, pub accesses: Vec<Access>, pub observed_inputs: BTreeSet<String>, pub uncovered_accesses: BTreeSet<String>, pub unobserved_inputs: BTreeSet<String>, pub successful_runs: BTreeSet<String>, pub successful_observations: BTreeSet<String>, pub candidate_filesets: BTreeSet<String>, pub declaration: Option<Declaration>, pub glob_suggestions: Vec<GlobSuggestion>, pub configuration_fragment: Option<Value>, pub successful_directories: BTreeSet<String>, pub suggestion_notes: Vec<String>, pub access_review: AccessReview,
}

Fields

context: Valueoutcome: Stringcoverage: Coveragedeclared_files: BTreeSet<String>mandatory_files: BTreeSet<String>

Configuration files qk always keys, regardless of target filesets.

accesses: Vec<Access>observed_inputs: BTreeSet<String>uncovered_accesses: BTreeSet<String>unobserved_inputs: BTreeSet<String>successful_runs: BTreeSet<String>

Successful runs contributing to the union; IDs prevent double counting.

successful_observations: BTreeSet<String>candidate_filesets: BTreeSet<String>

Exact observed paths for review.

declaration: Option<Declaration>glob_suggestions: Vec<GlobSuggestion>configuration_fragment: Option<Value>

A project.json fragment, always requiring review across configurations.

successful_directories: BTreeSet<String>suggestion_notes: Vec<String>access_review: AccessReview

Implementations

Source

impl TaskAnalysis

pub fn summarize(&mut self, run: &str)

pub fn merge(&mut self, previous: &Self) -> bool

Only observations of the same task definition, arguments and platform can support a union. Failed/aborted traces don’t support narrowing.